# ioOrbit

## Overview

Simple and flexible ML workflow engine. This library is meant to wrap all reusable code to simplify workflow implementation.

Supported functionality:

- Flexible logger 
- Firebase-admin / GCSFS file system handler
- API to communicate with RabbitMQ for event receiver/producer
- Workflow call helper
- Logger call helper


## License

Licensed under the Apache License, Version 2.0.